CREATE SCHEMA IF NOT EXISTS vit_public ;

SET search_path TO vit_public;

CREATE TABLE PRAEPARAT(
	PID NUMERIC(3) NOT NULL,
	NAME VARCHAR(20) NOT NULL,
	HERSTELLER VARCHAR(25) NOT NULL,
	PZN NUMERIC(8) NULL,
	ANZ NUMERIC(3) NULL,
	EINHEIT VARCHAR(10) NULL,
	TAGESDOSIS NUMERIC(2) NULL,
	GEWICHT NUMERIC(4,1) NULL,
	PREIS NUMERIC(4,2) NULL,
	GLUTENFREI CHAR(1) NULL,
	LACTOSEFREI CHAR(1) NULL,
	CONSTRAINT PRAEPARAT_PK
		PRIMARY KEY(PID),
	CONSTRAINT PZN_POSITIV
		CHECK(PZN > 0),
	CONSTRAINT ANZ_POSITIV
		CHECK(ANZ > 0),
	CONSTRAINT TAGESDOSIS_POSITIV
		CHECK(TAGESDOSIS > 0),
	CONSTRAINT GEWICHT_POSITIV
		CHECK(GEWICHT > 0),
	CONSTRAINT PREIS_NICHT_NEGATIV
		CHECK(PREIS >= 0),
	CONSTRAINT GLUTENFREI_J_N
		CHECK(GLUTENFREI IN ('J','N')),
	CONSTRAINT LACTOSEFREI_J_N
		CHECK(LACTOSEFREI IN ('J','N'))
);

-- Pruefziffer der PZN:
-- http://www.pruefziffernberechnung.de/P/PZN.shtml

INSERT INTO PRAEPARAT VALUES
(1, 'A-Z Vital', 'gesundleben', 04984944,
	60, 'Tabletten', 1,
	98.4,
	4.50, 'J', 'J');

INSERT INTO PRAEPARAT VALUES
(2, 'Centrum', 'Pfizer', 14170450,
	30, 'Tabletten', 1,
	36,
	12.95, NULL, NULL);

INSERT INTO PRAEPARAT VALUES
(3, 'A-Z Komplett', 'Abtei', 13876768,
	42, 'Tabletten', 1,
	50,
	6.39, 'J', 'J');

INSERT INTO PRAEPARAT VALUES
(4, 'A-Z Complete', 'Doppelherz aktiv', 02561576,
	40, 'Tabletten', 1,
	59.6,
	4.49, 'J', 'J');

INSERT INTO PRAEPARAT VALUES
(5, 'Kardiodrink', 'MensSana', 16356176,
	30, 'Sachet', 1,
	180,
	44.05, 'J', 'J');

INSERT INTO PRAEPARAT VALUES
(6, 'Mineraldrink', 'MensSana', 09486205,
	30, 'Sachet', 1,
	180,
	NULL, 'J', 'J');

INSERT INTO PRAEPARAT VALUES
(7, 'Magnesium Verla 300', 'Verla-Pharm Arzneimittel', 01316917,
	50, 'Beutel', 1,
	NULL,
	NULL, 'J', 'J');

-- ============================================================================

CREATE TABLE STOFF_KATEGORIE(
	KAT CHAR(1) NOT NULL,
	BEZEICHNUNG VARCHAR(30) NOT NULL,
	SORT_NR NUMERIC(1) NOT NULL,
	CONSTRAINT STOFF_KATEGORIE_PK
		PRIMARY KEY(KAT),
	CONSTRAINT STOFF_KATEGORIE_SORT_NR_EINDEUTIG
		UNIQUE(SORT_NR),
	CONSTRAINT KATEGORIE_SORT_NR_NICHT_NEGATIV
		CHECK(SORT_NR >= 0)
);

INSERT INTO STOFF_KATEGORIE VALUES ('V', 'Vitamine', 1);
INSERT INTO STOFF_KATEGORIE VALUES ('M', 'Mineralstoffe', 2);
INSERT INTO STOFF_KATEGORIE VALUES ('S', 'Spurenelemente', 3);
INSERT INTO STOFF_KATEGORIE VALUES ('C', 'Carotinoide', 4);
INSERT INTO STOFF_KATEGORIE VALUES ('A', 'Aminosäuren und -Verbindungen', 5);
INSERT INTO STOFF_KATEGORIE VALUES ('X', 'Sonstiges', 6);

-- Sekundäre Pflanzenstoffe?
-- Coenzym Q10?

-- ============================================================================

CREATE TABLE STOFF(
	VIT VARCHAR(20) NOT NULL,
	EINHEIT VARCHAR(10) NOT NULL,
	TAGESDOSIS NUMERIC(4) NULL,
	KAT CHAR(1) NOT NULL,
	CONSTRAINT STOFF_PK
		PRIMARY KEY(VIT),
	CONSTRAINT STOFF_REF_KATEGORIE
		FOREIGN KEY(KAT) REFERENCES STOFF_KATEGORIE(KAT),
	CONSTRAINT STOFF_TAGESDOSIS_NICHT_NEGATIV
		CHECK(TAGESDOSIS >= 0)
);

-- Referenzmengen aus EU-Lebensmittelinformationsverordnung
-- Verordnung (EU) Nr. 1169/2011
-- https://eur-lex.europa.eu/LexUriServ/LexUriServ.do?uri=OJ:L:2011:304:0018:0063:de:PDF
-- Anhang XIII, Seite 44 von 46 (22.11.2011)

INSERT INTO STOFF VALUES('A',                 'ug',  800,   'V');
INSERT INTO STOFF VALUES('B1/Thiamin',        'mg',    1.1, 'V');
INSERT INTO STOFF VALUES('B2/Riboflavin',     'mg',    1.4, 'V');
INSERT INTO STOFF VALUES('B3/Niacin',         'mg',   16,   'V');
INSERT INTO STOFF VALUES('B5/Pantothensäure', 'mg',    6,   'V');
INSERT INTO STOFF VALUES('B6',                'mg',    1.4, 'V');
INSERT INTO STOFF VALUES('B7/Biotin',         'ug',   50,   'V');
INSERT INTO STOFF VALUES('B9/Folsäure',       'ug',  200,   'V');
INSERT INTO STOFF VALUES('B12',               'ug',    2.5, 'V');
INSERT INTO STOFF VALUES('C',                 'mg',   80,   'V');
INSERT INTO STOFF VALUES('D',                 'ug',    5,   'V');
INSERT INTO STOFF VALUES('E',                 'mg',   12,   'V');
-- Vitamin E ist eine ganze Vitamin-Gruppe, die aus 8 verschiedenen
-- Verbindungen besteht.
-- Diese unterteilen sich in 4 Tocopherole und 4 Tocotrienole,
-- die jeweils durch den Vorsatz alpha, beta, gamma, delta unterschieden werden.
INSERT INTO STOFF VALUES('K',                 'ug',   75,   'V');
INSERT INTO STOFF VALUES('K2',                'ug',   75,   'V');
-- In der EU Lebensmittelverordnung ist nur Vitamin K aufgefuehrt.
-- Es sind aber verschiedene Stoffe:
-- Phyllochinon (Vitamin K1)
-- "eine Reihe isoprenylierter Menachinone" (Vitamin K2)
-- Besonders wirksam soll Menachinon K-4 sein.
-- "Das synthetische Vitamin K3 wird aus Toxizitätsgründen heute nicht mehr
--	verwendet."

INSERT INTO STOFF VALUES('Kalium',      'mg', 2000,   'M');
INSERT INTO STOFF VALUES('Calcium',     'mg',  800,   'M');
INSERT INTO STOFF VALUES('Natrium',     'mg',  NULL,  'M');
INSERT INTO STOFF VALUES('Phosphor',    'mg',  700,   'M');
INSERT INTO STOFF VALUES('Magnesium',   'mg',  375,   'M');
INSERT INTO STOFF VALUES('Chlor',       'mg',  800,   'M');

-- Spurenelemente: Im Koerper weniger als 50 mg pro Kilogramm Koerpergewicht.
INSERT INTO STOFF VALUES('Eisen',       'mg',   14,   'S');
INSERT INTO STOFF VALUES('Zink',        'mg',   10,   'S');
INSERT INTO STOFF VALUES('Kupfer',      'ug', 1000,   'S');
INSERT INTO STOFF VALUES('Mangan',      'mg',    2,   'S');
INSERT INTO STOFF VALUES('Fluor',       'mg',    3.5, 'S');
INSERT INTO STOFF VALUES('Selen',       'ug',   55,   'S');
INSERT INTO STOFF VALUES('Chrom',       'ug',   40,   'S');
INSERT INTO STOFF VALUES('Molybdän',    'ug',   50,   'S');
INSERT INTO STOFF VALUES('Jod',         'ug',  150,   'S');

-- Carotinoide:
INSERT INTO STOFF VALUES('Lutein',      'mg',  NULL,  'C'); -- bei Abtei ug
INSERT INTO STOFF VALUES('Lycopin',     'mg',  NULL,  'C');
INSERT INTO STOFF VALUES('Zeaxanthin',  'ug',  NULL,  'C');

-- Aminosaeuren und Verbindungen:
INSERT INTO STOFF VALUES('L-Arginin',   'mg',  NULL,  'A');
INSERT INTO STOFF VALUES('L-Carnitin',  'mg',  NULL,  'A');

-- Sonstiges:
INSERT INTO STOFF VALUES('Q10',         'mg',  NULL,  'X');
INSERT INTO STOFF VALUES('Cholin',      'mg',  NULL,  'X');
INSERT INTO STOFF VALUES('Isoflavone',  'mg',  NULL,  'X');


-- ============================================================================

CREATE TABLE INHALT(
	PID NUMERIC(3) NOT NULL,
	VIT VARCHAR(20) NOT NULL,
	MENGE NUMERIC(5,1) NOT NULL,
	PROZENT NUMERIC(3) NULL,
	ANMERKUNG VARCHAR(70) NULL,
	CONSTRAINT INHALT_PK
		PRIMARY KEY(PID, VIT),
	CONSTRAINT INHALT_REF_PRAEPARAT
		FOREIGN KEY(PID) REFERENCES PRAEPARAT(PID),
	CONSTRAINT INHALT_REF_STOFF
		FOREIGN KEY(VIT) REFERENCES STOFF(VIT),
	CONSTRAINT INHALT_MENGE_POSITIV
		CHECK(MENGE > 0),
	CONSTRAINT INHALT_PROZENT_POSITIV
		CHECK(PROZENT > 0),
	CONSTRAINT INHALT_ANMERKUNG_NULL_ODER_NICHT_LEER
		CHECK(ANMERKUNG IS NULL OR TRIM(ANMERKUNG) != '')
		-- Bei Oracle sind NULL und der leere String identisch.
		-- Deswegen habe ich den Test auf Null extra hingeschrieben,
		-- obwohl CHECK-Constraints beim dritten Wahrheitswert
		-- als erfuellt gelten wuerden.
		-- So gibt es bei Oracle zumindest keinen Fehler,
		-- wenn man einen Nullwert einfuegt.
);

-- gesundleben A-Z Vital Tabletten:

INSERT INTO INHALT VALUES (1, 'A', 800, 100, 'Vitamin A (RE)');
INSERT INTO INHALT VALUES (1, 'E',  12, 100, 'Vitamin E (alpha-TE)');
INSERT INTO INHALT VALUES (1, 'C', 120, 150, NULL);
INSERT INTO INHALT VALUES (1, 'K',  30,  40, NULL);
INSERT INTO INHALT VALUES (1, 'B1/Thiamin', 2.1, 191, NULL);
INSERT INTO INHALT VALUES (1, 'B2/Riboflavin', 2.4, 171, NULL);
INSERT INTO INHALT VALUES (1, 'B6', 3, 214, NULL);
INSERT INTO INHALT VALUES (1, 'B12', 3, 120, NULL);
INSERT INTO INHALT VALUES (1, 'D', 5, 100, NULL);
INSERT INTO INHALT VALUES (1, 'B7/Biotin', 150, 300, 'Biotin');
INSERT INTO INHALT VALUES (1, 'B9/Folsäure', 300, 150, 'Folsäure');
INSERT INTO INHALT VALUES (1, 'B3/Niacin', 18, 113, 'Niacin (NE)');
INSERT INTO INHALT VALUES (1, 'B5/Pantothensäure', 6, 100, 'Pantothensäure');
INSERT INTO INHALT VALUES (1, 'Calcium', 199, 25, NULL);
INSERT INTO INHALT VALUES (1, 'Phosphor', 155, 22, NULL);
INSERT INTO INHALT VALUES (1, 'Magnesium', 100, 27, NULL);
INSERT INTO INHALT VALUES (1, 'Eisen', 5, 36, NULL);
INSERT INTO INHALT VALUES (1, 'Jod', 100, 67, NULL);
INSERT INTO INHALT VALUES (1, 'Kupfer', 1040, 104, NULL);
INSERT INTO INHALT VALUES (1, 'Mangan', 1, 50, NULL);
INSERT INTO INHALT VALUES (1, 'Chrom', 60, 150, NULL);
INSERT INTO INHALT VALUES (1, 'Molybdän', 80, 160, NULL);
INSERT INTO INHALT VALUES (1, 'Selen', 25, 45, NULL);
INSERT INTO INHALT VALUES (1, 'Zink', 5, 50, NULL);
INSERT INTO INHALT VALUES (1, 'Q10', 2, NULL, 'Coenzym Q10');
INSERT INTO INHALT VALUES (1, 'Lutein', 2, NULL, NULL);

-- Centrum:

INSERT INTO INHALT VALUES (2, 'A', 800, 100,
				'Vitamin A (RE) (25% als Beta-Carotin)');
INSERT INTO INHALT VALUES (2, 'E',  15, 125, 'Vitamin E (alpha-TE)');
INSERT INTO INHALT VALUES (2, 'C', 100, 125, NULL);
INSERT INTO INHALT VALUES (2, 'K',  30,  40, NULL);
INSERT INTO INHALT VALUES (2, 'B1/Thiamin', 1.4, 127, 'Thiamin');
INSERT INTO INHALT VALUES (2, 'B2/Riboflavin', 1.75, 125, 'Riboflavin');
INSERT INTO INHALT VALUES (2, 'B6', 2, 143, NULL);
INSERT INTO INHALT VALUES (2, 'B12', 2.5, 100, NULL);
INSERT INTO INHALT VALUES (2, 'D', 5, 100, NULL);
INSERT INTO INHALT VALUES (2, 'B7/Biotin', 62.5, 125, 'Biotin');
INSERT INTO INHALT VALUES (2, 'B9/Folsäure', 200, 100, 'Folsäure');
INSERT INTO INHALT VALUES (2, 'B3/Niacin', 20, 125, 'Niacin (NE)');
INSERT INTO INHALT VALUES (2, 'B5/Pantothensäure', 7.5, 125, 'Pantothensäure');
INSERT INTO INHALT VALUES (2, 'Calcium', 162, 20, NULL);
INSERT INTO INHALT VALUES (2, 'Phosphor', 125, 18, NULL);
INSERT INTO INHALT VALUES (2, 'Magnesium', 100, 27, NULL);
INSERT INTO INHALT VALUES (2, 'Eisen', 5, 36, NULL);
INSERT INTO INHALT VALUES (2, 'Jod', 100, 67, NULL);
INSERT INTO INHALT VALUES (2, 'Kupfer',  500, 50, NULL);
INSERT INTO INHALT VALUES (2, 'Mangan', 2, 100, NULL);
INSERT INTO INHALT VALUES (2, 'Chrom', 40, 100, NULL);
INSERT INTO INHALT VALUES (2, 'Molybdän', 50, 100, NULL);
INSERT INTO INHALT VALUES (2, 'Selen', 30, 55, NULL);
INSERT INTO INHALT VALUES (2, 'Zink', 5, 50, NULL);

-- Abtei A-Z Komplett

INSERT INTO INHALT VALUES (3, 'Lutein', 0.5, NULL, NULL); -- 500 ug
INSERT INTO INHALT VALUES (3, 'A', 800, 100, 'Vitamin A (RE)');
INSERT INTO INHALT VALUES (3, 'B1/Thiamin', 1.1, 100, 'Vitamin B1');
INSERT INTO INHALT VALUES (3, 'B2/Riboflavin', 1.4, 100, 'Vitamin B2');
INSERT INTO INHALT VALUES (3, 'B6', 1.4, 100, 'Vitamin B6');
INSERT INTO INHALT VALUES (3, 'B12', 2.5, 100, 'Vitamin B12');
INSERT INTO INHALT VALUES (3, 'B7/Biotin', 50, 100, 'Biotin');
INSERT INTO INHALT VALUES (3, 'B9/Folsäure', 200, 100, 'Folsäure');
INSERT INTO INHALT VALUES (3, 'B3/Niacin', 16, 100, 'Niacin (NE)');
INSERT INTO INHALT VALUES (3, 'B5/Pantothensäure', 6, 100, 'Pantothensäure');
INSERT INTO INHALT VALUES (3, 'C', 80, 100, 'Vitamin C');
INSERT INTO INHALT VALUES (3, 'D', 5, 100, 'Vitamin D');
INSERT INTO INHALT VALUES (3, 'E',  12, 100, 'Vitamin E (alpha-TE)');
INSERT INTO INHALT VALUES (3, 'K',  75,  100, 'Vitamin K');
INSERT INTO INHALT VALUES (3, 'Calcium', 120, 15, NULL);
INSERT INTO INHALT VALUES (3, 'Chrom', 40, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Eisen', 14, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Fluor', 3.5, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Jod', 150, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Kupfer',  1000, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Magnesium', 56, 15, NULL);
INSERT INTO INHALT VALUES (3, 'Mangan', 2, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Molybdän', 50, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Selen', 55, 100, NULL);
INSERT INTO INHALT VALUES (3, 'Zink', 10, 100, NULL);
-- (Kein Phosphor enthalten)

-- Doppelherz aktiv A-Z Complete

INSERT INTO INHALT VALUES (4, 'A', 400, 50, 'Vitamin A (RE)');
INSERT INTO INHALT VALUES (4, 'Lutein', 1.5, NULL, NULL); -- 1500 ug
INSERT INTO INHALT VALUES (4, 'D', 5, 100, 'Vitamin D');
INSERT INTO INHALT VALUES (4, 'E',  10, 83, 'Vitamin E (alpha-TE)');
INSERT INTO INHALT VALUES (4, 'K',  20,  27, 'Vitamin K');
INSERT INTO INHALT VALUES (4, 'C', 150, 188, 'Vitamin C');
INSERT INTO INHALT VALUES (4, 'B1/Thiamin', 3.5, 318, 'Vitamin B1');
INSERT INTO INHALT VALUES (4, 'B2/Riboflavin', 4.0, 286, 'Vitamin B2');
INSERT INTO INHALT VALUES (4, 'B3/Niacin', 18, 113, 'Niacin (NE)');
INSERT INTO INHALT VALUES (4, 'B6', 5.0, 357, 'Vitamin B6');
INSERT INTO INHALT VALUES (4, 'B9/Folsäure', 450, 225, 'Folsäure');
INSERT INTO INHALT VALUES (4, 'B12', 2.5, 100, 'Vitamin B12');
INSERT INTO INHALT VALUES (4, 'B7/Biotin', 300, 600, 'Biotin');
INSERT INTO INHALT VALUES (4, 'B5/Pantothensäure', 12, 200, 'Pantothensäure');
INSERT INTO INHALT VALUES (4, 'Calcium', 137, 17, NULL);
INSERT INTO INHALT VALUES (4, 'Phosphor', 105, 15, NULL);
INSERT INTO INHALT VALUES (4, 'Magnesium', 56.3, 15, NULL);
INSERT INTO INHALT VALUES (4, 'Eisen', 2.1, 15, NULL);
INSERT INTO INHALT VALUES (4, 'Zink', 5, 50, NULL);
INSERT INTO INHALT VALUES (4, 'Kupfer', 900, 90, NULL); -- 0.9 mg
INSERT INTO INHALT VALUES (4, 'Selen', 10, 18, NULL);
INSERT INTO INHALT VALUES (4, 'Chrom', 25, 63, NULL);
INSERT INTO INHALT VALUES (4, 'Molybdän', 20, 40, NULL);
INSERT INTO INHALT VALUES (4, 'Jod', 100, 67, NULL);

-- MensSana Kardiodrink:

INSERT INTO INHALT VALUES (5, 'A', 167, 21,
    'Beta-Carotin 1 mg entspricht Vitamin A 167ug RE (Retinol-Äquivalente)');
INSERT INTO INHALT VALUES (5, 'B1/Thiamin', 2.2, 200, 'Thiamin (B1)');
INSERT INTO INHALT VALUES (5, 'B2/Riboflavin', 2.8, 200, 'Riboflavin (B2)');
INSERT INTO INHALT VALUES (5, 'B3/Niacin', 16, 100,
	'Niacin 16mg NE (Niacin-Äquivalente)');
INSERT INTO INHALT VALUES (5, 'B5/Pantothensäure', 6, 100,
	'Pantothensäure (B5)');
INSERT INTO INHALT VALUES (5, 'B6', 2.8, 200, 'Vitamin B6');
INSERT INTO INHALT VALUES (5, 'B7/Biotin', 50, 100, 'Biotin (B7)');
INSERT INTO INHALT VALUES (5, 'B9/Folsäure', 400, 200, 'Folsäure (B9)');
INSERT INTO INHALT VALUES (5, 'B12', 12.5, 500, 'Vitamin B12');
INSERT INTO INHALT VALUES (5, 'C', 160, 200, 'Vitamin C');
INSERT INTO INHALT VALUES (5, 'D', 20, 400, 'Vitamin D 20ug = 800 IE');
INSERT INTO INHALT VALUES (5, 'E', 12, 100, 'Vitamin E 12mg alpha-TE');
INSERT INTO INHALT VALUES (5, 'K2', 40, 53, 'Vitamin K2');
INSERT INTO INHALT VALUES (5, 'Chrom', 40, 100, NULL);
INSERT INTO INHALT VALUES (5, 'Magnesium', 112.5, 30, NULL);
INSERT INTO INHALT VALUES (5, 'Selen', 55, 100, NULL);
INSERT INTO INHALT VALUES (5, 'Zink', 10, 100, NULL);
INSERT INTO INHALT VALUES (5, 'L-Arginin', 250, NULL, NULL);
INSERT INTO INHALT VALUES (5, 'L-Carnitin', 250, NULL, NULL);
INSERT INTO INHALT VALUES (5, 'Cholin', 500, NULL, NULL);
INSERT INTO INHALT VALUES (5, 'Q10', 50, NULL, 'Coenzym Q10');
INSERT INTO INHALT VALUES (5, 'Isoflavone', 35, NULL,
	'Isoflavone aus Sojabohnenextrakt');
INSERT INTO INHALT VALUES (5, 'Lutein', 16.7, NULL,
	'Lutein aus Tagetesextrakt');
INSERT INTO INHALT VALUES (5, 'Zeaxanthin', 500, NULL,
	'Zeaxanthin aus Tagetesextrakt');
INSERT INTO INHALT VALUES (5, 'Lycopin', 3, NULL,
	'Lycopin aus Tomatenextrakt');

-- MensSana Mineraldrink:

INSERT INTO INHALT VALUES (6, 'A', 167, 21,
    'Beta-Carotin 1 mg entspricht Vitamin A 167ug RE (Retinol-Äquivalente)');
INSERT INTO INHALT VALUES (6, 'B1/Thiamin', 2.2, 200, 'Thiamin (B1)');
INSERT INTO INHALT VALUES (6, 'B2/Riboflavin', 2.8, 200, 'Riboflavin (B2)');
INSERT INTO INHALT VALUES (6, 'B3/Niacin', 32, 200,
	'Niacin 32mg NE (Niacin-Äquivalente)');
INSERT INTO INHALT VALUES (6, 'B5/Pantothensäure', 12, 200,
	'Pantothensäure (B5)');
INSERT INTO INHALT VALUES (6, 'B6', 2.8, 200, 'Vitamin B6');
INSERT INTO INHALT VALUES (6, 'B7/Biotin', 100, 200, 'Biotin (B7)');
INSERT INTO INHALT VALUES (6, 'B9/Folsäure', 200, 100, 'Folsäure (B9)');
INSERT INTO INHALT VALUES (6, 'B12', 5, 200, 'Vitamin B12');
INSERT INTO INHALT VALUES (6, 'C', 80, 100, 'Vitamin C');
INSERT INTO INHALT VALUES (6, 'D', 5, 100, 'Vitamin D 5ug = 200 IE');
INSERT INTO INHALT VALUES (6, 'E', 12, 100, 'Vitamin E 12mg alpha-TE');
INSERT INTO INHALT VALUES (6, 'Kalium', 499, 25, NULL);
INSERT INTO INHALT VALUES (6, 'Magnesium', 375, 100, NULL);
INSERT INTO INHALT VALUES (6, 'Natrium', 43.3, NULL, NULL);
INSERT INTO INHALT VALUES (6, 'Selen', 27.5, 50, NULL);
INSERT INTO INHALT VALUES (6, 'Zink', 5, 50, NULL);

-- Magnesium Verla 300:

INSERT INTO INHALT VALUES (7, 'Magnesium', 300, 80, NULL);

-- ============================================================================

CREATE TABLE ZUTAT(
	PID NUMERIC(3) NOT NULL,
	SEQ NUMERIC(3) NOT NULL,
	NAME VARCHAR(90) NOT NULL,
	Anmerkung VARCHAR(20) NULL,
	CONSTRAINT ZUTAT_PK
		PRIMARY KEY(PID, SEQ),
	CONSTRAINT ZUTAT_REF_PRAEPARAT
		FOREIGN KEY(PID) REFERENCES PRAEPARAT,
	CONSTRAINT ZUTAT_SEQ_POSITIV
		CHECK(SEQ > 0)
);

-- gesundleben A-Z Vital Tabletten:

INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  1, 'Dicalciumphosphat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  2, 'Füllstoff mikrokristalline Cellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  3, 'Magnesiumoxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  4, 'Ascorbinsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  5, 'Verdickungsmittel Hydroxypropylmethylcellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  6, 'DL-alpha-Tocopherylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  7, 'Lutein');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  8, 'Farbstoff Titandioxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1,  9, 'Füllstoff vernetzte Natriumcarboxymethylcellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 10, 'Füllstoff Maltrodextrin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 11, 'Nicotinamid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 12, 'Eisenfumarat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 13, 'Trennmittel Siliziumdioxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 14, 'Überzugsmittel Polyvinylalkohol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 15, 'Calcium-D-Phantothenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 16, 'Vitamin-A-Acetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 17, 'Trennmittel Magnesiumsalze der Speisefettsäuren');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 18, 'Überzugsmittel Polyethylenglycol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 19, 'Zinkoxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 20, 'Füllstoff Polydextrose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 21, 'Kupfersulfat-Pentahydrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 22, 'Pyridoxinhydrochlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 23, 'Trennmittel Talkum');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 24, 'Thiaminmononitrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 25, 'Riboflavin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 26, 'Mangansulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 27, 'Cholecalciferol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 28, 'Coenzym Q10');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 29, 'Phytomenadion');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 30, 'Folsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 31, 'Füllstoff Maisstärke');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 32, 'Biotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 33, 'Füllstoff Tricalciumphosphat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 34, 'Chrom-(III)-chlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 35, 'Natriummolybdat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 36, 'Kaliumjodid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 37, 'Antioxidationsmittel L-(+)-Weinsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 38, 'Verdickungsmittel Natriumcarboxymethylcellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 39, 'Natriumselenit');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(1, 40, 'Cyanocobalamin');

-- Centrum:
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  1, 'Calciumhydrogenphosphat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  2, 'Magnesiumoxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  3, 'Füllstoffe E 460, E 464, E 1200');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  4, 'L-Ascorbinsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  5, 'Kaliumchlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  6, 'Stabilisator: E 1202');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  7, 'DL-alpha-Tocopherylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  8, 'Nicotinamid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2,  9, 'Eisen-II-fumerat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 10, 'Calcium-D-Pantothenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 11, 'Zinkoxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 12, 'Mangan-II-sulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 13, 'Emulgator: E 470b');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 14, 'Trennmittel: E 551');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 15, 'E 553b');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 16, 'Gelatine');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 17, 'Pyridoxinhydrochlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 18, 'Thiaminmononitrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 19, 'Riboflavin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 20, 'Beta-Carotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 21, 'Kupfersulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 22, 'Pflanzliche Öle (Kokos-, Palmkernöl)');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 23, 'Retinylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 24, 'Pteroylmonoglutaminsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 25, 'Chrom-III-chlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 26, 'Natriummolybdat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 27, 'Kaliumjodid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 28, 'Natriumselenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 29, 'D-Biotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 30, 'Antioxidationsmittel: E 321');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 31, 'Phyllochinon');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 32, 'Cholecalciferol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 33, 'Cyanocobalamin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(2, 34, 'Farbstoffe: E 171, E 132');

-- Abtei A-Z Komplett:
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  1, 'Calciumcarbonat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  2, 'Füllstoffe Hydroxypropylmethylcellulose, Cellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  3, 'Maltodextrin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  4, 'Magnesiumhydroxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  5, 'Trennmittel Siliziumdioxid, Speisefettsäuren, ' ||
			'Magnesiumsalze der Speisefettsäuren');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  6, 'Vitamin C');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  7, 'Eisenfumarat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  8, 'Vitamin E');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3,  9, 'Nicotinamid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 10, 'Zinkoxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 11, 'Calcium-D-Pantothenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 12, 'Natriumfluorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 13, 'Mangansulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 14, 'Farbstoffe Titandioxid, Eisenoxide und Eisenhydroxide');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 15, 'Kupfersulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 16, 'Vitamin B6');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 17, 'Vitamin B2');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 18, 'Vitamin B1');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 19, 'Vitamin A');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 20, 'luteinhaltiger Ringelblumenextrakt');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 21, 'Folsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 22, 'Chromchlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 23, 'Kaliumiodid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 24, 'Natriumselenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 25, 'Natriummolybdat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 26, 'Vitamin K');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 27, 'Biotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 28, 'Vitamin D');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(3, 29, 'Vitamin B12');

-- MensSana Kardiodrink:
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  1, 'Füllstoffe Cellulose, Isomalt und ' ||
			'Hydroxypropylmethylcellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  2, 'Dicalciumphosphat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  3, 'L-Ascorbinsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  4, 'Magnesiumoxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  5, 'Trennmittel Speisefettsäuren');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  6, 'Magnesiumsalze der Speisefettsäuren');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  7, 'Talkum und Siliciumdioxid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  8, 'modifizierte Stärke');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4,  9, 'Nicotinamid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 10, 'DL-alpha-Tocopherylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 11, 'Zinksulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 12, 'Calcium-D-pantothenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 13, 'Farbstoffe Titandioxid und Eisenoxide und Eisenhydroxide');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 14, 'Eisensulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 15, 'Pyridoxinhydrochlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 16, 'Thiaminmononitrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 17, 'Riboflavin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 18, 'Maisstärke');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 19, 'Kupfersulfat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 20, 'Überzugsmittel Hydroxypropylcellulose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 21, 'Calciumcarbonat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 22, 'Lutein aus Studentenblumen');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 23, 'pflanzliche Öle (Kokos, Palm) ' ||
			'in veränderlichen Gewichtsanteilen');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 24, 'Glucosesirup');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 25, 'Retinylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 26, 'Pteroylmonoglutaminsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 27, 'D-Biotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 28, 'Kaliumiodid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 29, 'Chrom-(III)-Chlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 30, 'Natriummolybdat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 31, 'Natriumselenit');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 32, 'Phytomenadion');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 33, 'Cholecalciferol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(4, 34, 'Cyanocobalamin');

-- MensSana Kardiodrink:
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  1, 'Inulin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  2, 'Cholinbitartrate');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  3, 'Magnesiumcitrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  4, 'L-Carnitintartrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  5, 'L-Agrininhydrochlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  6, 'Säuerungsmittel Zitronensäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  7, 'Aroma');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  8, 'L-Ascorbinsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5,  9, 'Tagetesextrakt');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 10, 'Süßungsmittel (Steviolglycoside, Sucralose)');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 11, 'Sojabohnenextrakt');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 12, 'Zinkgluconat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 13, 'Tomatenextrakt');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 14, 'Coenzym Q10');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 15, 'D-alpha-Tocopherylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 16, 'Chromhefe');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 17, 'Nicotinamid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 18, 'Selenmethionin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 19, 'Calcium-D-phantothenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 20, 'Beta Carotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 21, 'PyridoxinHCL');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 22, 'ThiaminHCL');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 23, 'Riboflavin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 24, 'Pteroylmonoglutaminsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 25, 'D-Biotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 26, 'Menachinon-7');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 27, 'Cholecalciferol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(5, 28, 'Cyanocobalamin');

-- MensSana Mineraldrink:
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  1, 'Tri-Magnesiumdicitrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  2, 'Tri-Kaliumcitrat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  3, 'Säuerungsmittel Zitronensäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  4, 'Maltrodextrin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  5, 'Natriumhydrogenkarbonat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  6, 'Trennmittel Tri-Calciumphosphat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  7, 'L-Ascorbinsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  8, 'Aroma');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6,  9, 'D-alpha-Tocopherylacetat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 10, 'Zinkgluconat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 11, 'Nicotinamid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 12, 'Süßungsmittel Steviolglucoside'); -- So gedruckt. glycoside?
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 13, 'Calcium-D-Pantothenat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 14, 'Beta Carotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 15, 'Cyanocobalamin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 16, 'Süßungsmittel Sucralose');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 17, 'Pyridoxinhydrochlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 18, 'Thiaminhydrochlorid');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 19, 'Riboflavin-5-phosphat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 20, 'Trennmittel Magnesiumsalze der Speisefettsäuren (pflanzlich)');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 21, 'Cholecalciferol');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 22, 'Pteroylmonoglutaminsäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 23, 'Biotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(6, 24, 'L-Selenomethionin');

-- Magnesium Verla 300:
INSERT INTO ZUTAT(PID, SEQ, NAME, ANMERKUNG) VALUES
	(7,  1, 'Magnesiumcitrat', '48%');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(7,  2,'Orangenfruchtpulver (Maltodextrin, Orangensaftkonzentrat 10%)');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(7,  3, 'Säuerungsmittel Zitronensäure');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(7,  4, 'Säuereregulator Kaliumhydrogencarbonat');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(7,  5, 'Farbstoff Beta-Carotin');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(7,  6, 'Aromen (Orange, Zitrone)');
INSERT INTO ZUTAT(PID, SEQ, NAME) VALUES
	(7,  7, 'Süßungsmittel Cyclamat und Saccharin');


GRANT USAGE ON SCHEMA vit_public TO student;
GRANT SELECT ON ALL TABLES IN SCHEMA vit_public to student;